@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -124,6 +124,9 @@ addressbooklistmodule.prototype.execute = function(type, action)
 			// Content in addressbook is loaded and table widget is added so call resize function.
 			if (window.onresize)
 				window.onresize();
+			// empty old selected messages if there was any.
+			if(this.selectedMessages)
+				this.selectedMessages = new Array();
 			break;
 		case "hierarchy":
 			this.updateHierarchy(action);
