@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -256,20 +256,21 @@ TableCompactView.prototype.renderRow = function(elemid, row)
 				case "ipm_schedule_meeting_canceled":
 				case "report_ipm_note_ipnnrn":
 				case "report_ipm_note_ipnrn":
-					messageClass = "ipm_readmail read_unread";
+					messageClass = "ipm_readmail";
 					
 					var messageUnsent = row.getElementsByTagName("message_unsent")[0];
 					if(messageUnsent && messageUnsent.firstChild) {
-						messageClass = "ipm_createmail read_unread";
+						messageClass = "ipm_createmail";
 					}
 					break;
 				case "ipm_taskrequest":
 				case "ipm_taskrequest_accept":
 				case "ipm_taskrequest_decline":
 				case "ipm_taskrequest_update":
-					messageClass = "ipm_task read_unread";
+					messageClass = "ipm_task";
 					break;
 			}
+			messageClass += " read_unread";
 		}
 
 		// Get message flag (unread)
