@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -102,18 +102,21 @@ function get_mapi_error_name($errcode=null)
 	}
 	
 	if ($errcode !== 0){
-		$allConstants = get_defined_constants(true);
+		// get_defined_constants(true) is preferred, but crashes PHP
+		// https://bugs.php.net/bug.php?id=61156
+		$allConstants = get_defined_constants();
 
-		foreach($allConstants['user'] as $key => $value){
-			$prefix = substr($key, 0, 7);
-			if ($prefix == "MAPI_E_" || $prefix == "MAPI_W_") {
-				/**
-				 * If PHP encounters a number beyond the bounds of the integer type,
-				 * it will be interpreted as a float instead, so when comparing these error codes
-				 * we have to manually typecast value to integer, so float will be converted in integer,
-				 * but still its out of bound for integer limit so it will be auto adjusted to minus value
-				 */
-				if ($errcode == (int) $value){
+		foreach ($allConstants as $key => $value) {
+			/**
+			 * If PHP encounters a number beyond the bounds of the integer type,
+			 * it will be interpreted as a float instead, so when comparing these error codes
+			 * we have to manually typecast value to integer, so float will be converted in integer,
+			 * but still its out of bound for integer limit so it will be auto adjusted to minus value
+			 */
+			if ($errcode == (int) $value) {
+				// Check that we have an actual MAPI error or warning definition
+				$prefix = substr($key, 0, 7);
+				if ($prefix == "MAPI_E_" || $prefix == "MAPI_W_") {
 					return $key;
 				}
 			}
