@@ -310,10 +310,14 @@
 							array_push($searchprops, $prop);
 					}
 
-					$searchterms = preg_split("/ +/", $searchterms);
-					
+					$searchterms = preg_split("/[\.\/\~\,\ \@]+/", $searchterms);
+
 					$res_and = array();
 					foreach($searchterms as $term) {
+						if(empty($term)) {
+							continue;
+						}
+
 						$res_or = array();
 						
 						foreach($searchprops as $property) {
